@@ -1,7 +1,7 @@
 package App::KwaliteeUtils;
 
-our $DATE = '2019-07-03'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2021-05-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -67,7 +67,7 @@ App::KwaliteeUtils - Utilities related to Kwalitee
 
 =head1 VERSION
 
-This document describes version 0.002 of App::KwaliteeUtils (from Perl distribution App-KwaliteeUtils), released on 2019-07-03.
+This document describes version 0.003 of App::KwaliteeUtils (from Perl distribution App-KwaliteeUtils), released on 2021-05-25.
 
 =head1 DESCRIPTION
 
@@ -86,7 +86,7 @@ This distributions provides the following command-line utilities:
 
 Usage:
 
- calc_kwalitee(%args) -> [status, msg, payload, meta]
+ calc_kwalitee(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Calculate kwalitee of a local distribution.
 
@@ -109,15 +109,16 @@ less-than-full score.
 
 =item * B<raw> => I<true>
 
+
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
+($reason) is a string containing error message, or "OK" if status is
+200. Third element ($payload) is optional, the actual result. Fourth
+element (%result_meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
@@ -153,7 +154,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by perlancar@cpan.org.
+This software is copyright (c) 2021 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
